#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# cygwin command
# 
# executes a cygwin command inside the opensecurity project
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2013 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import os
import subprocess
import sys

# local
from environment import Environment


# ------------------------------------------------------------
# code


class Cygwin(object):

    """Some nifty methods working with Cygwin"""
    
    def __call__(self, command, stdin = subprocess.PIPE, stdout = subprocess.PIPE, stderr = subprocess.PIPE):
        """make an instance of this object act as a function"""
        return self.execute(command, stdin, stdout, stderr)

        
    @staticmethod
    def root():
        """get the path to our local cygwin installment"""
        return os.path.join(Environment('OpenSecurity').prefix_path, '..', 'cygwin')


    def execute(self, command, stdin = subprocess.PIPE, stdout = subprocess.PIPE, stderr = subprocess.PIPE):
        """execute a cygwin shell command
        
        command is list of arguments like ['/bin/ls', '-al', '-h']
        
        a Popen object is returned"""
        command_path = Cygwin.root() + os.sep.join(command[0].split('/'))
        command = [command_path] + command[1:]
        
        return subprocess.Popen(command, shell = False, stdin = stdin, stdout = stdout, stderr = stderr)
        
        
    @staticmethod
    def is_X11_running():
        """check if we can connect to a X11 running instance"""
        p = Cygwin()(['/bin/bash', '-c', 'DISPLAY=:0 /usr/bin/xset -q'])
        stdout, stderr = p.communicate()
        return p.returncode == 0
        
        
    @staticmethod
    def start_X11():
        """start X11 in the background (if not already running) on DISPLAY=:0"""
        
        # do not start if already running
        if Cygwin.is_X11_running():
            return
            
        # launch X11 (forget output and return immediately)
        p = Cygwin()(['/bin/bash', '--login', '-i', '-c', ' X :0 -multiwindow'], stdin = None, stdout = None, stderr = None)
        
    
# start
if __name__ == "__main__":

    # execute what is given on the command line
    c = Cygwin()
    p = c(sys.argv[1:])
    
    # wait until the process finished and grab the output
    stdout, stderr = p.communicate()
    print('=== call result on stdout: ===\n' + stdout)
    print('=== call result on stderr: ===\n' + stderr)
    
