#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# opensecurityd
# 
# the opensecurityd as RESTful server
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2013 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import os
import os.path
import subprocess
import sys
import web
from vmmanager.vmmanager import VMManager

# local
from environment import Environment


# ------------------------------------------------------------
# const

__version__ = "0.1"


"""All the URLs we know mapping to class handler"""
opensecurity_urls = (
    '/device_change',           'os_device_change',
    '/sdvms',                   'os_sdvms',
    '/vms',                     'os_vms',
    '/vms/(.*)',                'os_vm',
    '/',                        'os_root'
)


# ------------------------------------------------------------
# vars

# Global VMManager instance
gvm_mgr = VMManager()


# ------------------------------------------------------------
# code


class os_device_change:
    """OpenSecurity '/device_change' handler"""
    
    def GET(self):
        #gvm_mgr.configureHostNetworking()
        print 'received device_change'
        return "os_device_change"


class os_sdvms:
    """OpenSecurity '/sdvms' handler"""
    
    def GET(self):
        return gvm_mgr.listSDVM() 
            

class os_vm:
    """OpenSecurity '/vms/VM' handler"""
    
    def GET(self, name):
        return gvm_mgr.getVMInfo(name)
            

class os_vms:
    """OpenSecurity '/vms' handler"""
    
    def GET(self):
        return gvm_mgr.listVM() 
            

class os_root:
    """OpenSecurity '/' handler"""
    
    def GET(self):
        res = "'os_server': { "
        res += "'version': '" + __version__ + "', "
        res += "'virtualbox_path': '" + gvm_mgr.vBoxPath + "', "
        res += "'machine_folder': '" + gvm_mgr.getDefaultMachineFolder() + "' "
        res += "}"
        return res


# start
if __name__ == "__main__":
    server = web.application(opensecurity_urls, globals())
    server.run()

